[![][License img]][License]
<span>&nbsp;</span>
[![][MainRepo img]][MainRepo]
<span>&nbsp;</span>
[![][AltRepo img]][AltRepo]

<br style="margin: 1rem 0;" />

<a href="http://lpsc.in2p3.fr/"              target="_blank" style="margin-right: 2rem;"><img src="https://ami.web.cern.ch/images/logo_lpsc.png" alt="LPSC" height="72" /></a>
&nbsp;&nbsp;&nbsp;
<a href="http://www.in2p3.fr/"               target="_blank" style="margin-right: 2rem;"><img src="https://ami.web.cern.ch/images/logo_in2p3.png" alt="IN2P3" height="72" /></a>
&nbsp;&nbsp;&nbsp;
<a href="http://www.univ-grenoble-alpes.fr/" target="_blank" style="margin-right: 0rem;"><img src="https://ami.web.cern.ch/images/logo_uga.png" alt="UGA" height="72" /></a>

TF2-SOM
=======

This is a fast Tensorflow 2 implementation of the Self Organizing Maps (SOM) running on arbitrarily large datasets.

<img src="https://odier-io.github.io/tf2-som/som.png" alt="" height="250" />

Documentation
=============

https://odier-io.github.io/tf2-som/

Demo
====

[🔗 Click there](https://github.com/odier-io/tf2-som/blob/master/demo/demo.ipynb)

Authors
=======

- [Jérôme ODIER](https://annuaire.in2p3.fr/4121-4467/jerome-odier) ([CNRS/LPSC](https://lpsc.in2p3.fr/))
- [Nora ACHBAK](https://annuaire.in2p3.fr/7591-10426/nora-achbak) ([CNRS/LPSC](https://lpsc.in2p3.fr/))

[License]:http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.txt
[License img]:https://img.shields.io/badge/license-CeCILL--C-blue.svg

[MainRepo]:https://gitlab.in2p3.fr/jodier/tf2_som
[MainRepo img]:https://img.shields.io/badge/Main%20Repo-gitlab.in2p3.fr-success

[AltRepo]:https://github.com/odier-xyz/tf2_som
[AltRepo img]:https://img.shields.io/badge/Alt%20Repo-github.com-success
